"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createReactHooks = exports.ZodiosReact = void 0;
const react_query_1 = require("react-query");
const utils_1 = require("../utils");
class ZodiosReact {
    constructor(apiName, zodios) {
        this.apiName = apiName;
        this.zodios = zodios;
    }
    useQuery(path, config, queryOptions) {
        const params = (0, utils_1.pick)(config, [
            "params",
            "queries",
        ]);
        const keys = [this.apiName, path, params];
        const query = () => this.zodios.get(path, config);
        return (0, react_query_1.useQuery)(keys, query, queryOptions);
    }
    useMutation(method, path, mutationOptions) {
        const mutation = ({ data, config }) => {
            return this.zodios.request({
                ...config,
                method,
                url: path,
                data,
            });
        };
        return (0, react_query_1.useMutation)(mutation, mutationOptions);
    }
    useGet(path, config, queryOptions) {
        return this.useQuery(path, config, queryOptions);
    }
    usePost(path, mutationOptions) {
        return this.useMutation("post", path, mutationOptions);
    }
    usePut(path, mutationOptions) {
        return this.useMutation("put", path, mutationOptions);
    }
    usePatch(path, mutationOptions) {
        return this.useMutation("patch", path, mutationOptions);
    }
    useDelete(path, mutationOptions) {
        return this.useMutation("delete", path, mutationOptions);
    }
}
exports.ZodiosReact = ZodiosReact;
function createReactHooks(apiName, zodios) {
    return new ZodiosReact(apiName, zodios);
}
exports.createReactHooks = createReactHooks;
